@@ -1,3 +1,6 @@
+from pkgutil import extend_path
+__path__ = extend_path(__path__, __name__)
+
 import abc
 import builtins
 import datetime
@@ -11,14 +14,15 @@ import typing_extensions
 from typeguard import check_type
 
 import aws_cdk._jsii
+import aws_cdk.integ_tests_alpha._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-solutions-constructs/aws-lambda-ssmstringparameter",
-    "2.51.0",
+    "2.54.1",
     __name__[0:-6],
-    "aws-lambda-ssmstringparameter@2.51.0.jsii.tgz",
+    "aws-lambda-ssmstringparameter@2.54.1.jsii.tgz",
 )
 
 __all__ = [
